#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <LittleFS.h>
#include <DHT.h>

IPAddress local_IP(192,168,4,2);
IPAddress gateway(192,168,4,1);
IPAddress subnet(255,255,252,0);
int WiFi_OK;
int WiFi_Mode = 1;
int EtatLED = 1;
ESP8266WebServer server(80);
String Page;
DHT dht_12_DHT11(12,DHT11);

// Décrire cette fonction
void FonctionURLNotFound() {
  handleFileRead(server.uri());
}

String getContentType(String filename) 
{ // convert the file extension to the MIME type
  if (filename.endsWith(".html")) return "text/html";
  else if (filename.endsWith(".css")) return "text/css";
  else if (filename.endsWith(".js")) return "application/javascript";
  else if (filename.endsWith(".ico")) return "image/x-icon";
  return "text/plain";
}

bool handleFileRead(String path) 
{ // send the right file to the client (if it exists)
  Serial.println("handleFileRead: " + path);
  if (path.endsWith("/")) path += "index.html";         // If a folder is requested, send the index file
  String contentType = getContentType(path);            // Get the MIME type
  if (LittleFS.exists(path)) {                            // If the file exists
    File file = LittleFS.open(path, "r");                 // Open it
    size_t sent = server.streamFile(file, contentType); // And send it to the client
    file.close();                                       // Then close the file again
    return true;
  }
  Serial.print("File :"); Serial.print(path);Serial.println(" Not Found");
  return false;                                         // If the file doesn't exist, return false
}

void ReadTemp()
{
  handleFileRead("/FancyThermoJSON.html");
}

// Décrire cette fonction
void MakeJSON() {
  String JSONData = "{ \"Temp\": " + String(dht_12_DHT11.readTemperature()) + ",  \"Hum\": " + String(dht_12_DHT11.readHumidity()) + "}\n";
  Serial.print("JSON Data ="); Serial.print(JSONData);
  server.send(200, "data/json", JSONData);
}



void setup() {
  Serial.begin(115200);
  WiFi_OK = WiFi.softAPConfig(local_IP, gateway, subnet);
  WiFi_OK &= WiFi.softAP("ESP8266_TH");
  Serial.println("\n\nDémarre Wifi");
  
  // Launch LittleFS file system | Démarre le système de fichier LittleFS
  if(!LittleFS.begin()){
    Serial.println("An Error has occurred while mounting LittleFS");
    return;
  }
  Serial.println("LittleFS Ready");
  String str = "";
  Dir dir = LittleFS.openDir("/");
  while (dir.next()) {
      str += dir.fileName();
      str += " / ";
      str += dir.fileSize();
      str += "\r\n";
  }
  Serial.print(str);
  dht_12_DHT11.begin();
  server.on("/", ReadTemp);
  server.on("/DataTemp.json", MakeJSON);
  server.onNotFound(FonctionURLNotFound);
  server.begin();
  EtatLED = 1;
  pinMode(2, OUTPUT);
  digitalWrite(2, EtatLED);
  Serial.println("Thermomètre prêt");
}

void loop() {
  server.handleClient();

}
